ChunkReadError

Enum ChunkReadError 

pub enum ChunkReadError {
    ChunkNotFound {
        position: RegionChunkPosition,
    },
    LengthExceedsMaximum {
        length: u32,
        maximum_length: u32,
    },
    UnsupportedCompressionScheme {
        compression_scheme: u8,
    },
    IOError {
        io_error: Error,
    },
    TagDecodeError {
        tag_decode_error: TagDecodeError,
    },
}
Possible errors while loading the chunk.

Variants



ChunkNotFound

Chunk at specified coordinates inside region not found.

Fields



LengthExceedsMaximum

Chunk length overlaps declared maximum.

This should not occur under normal conditions.

Region file are corrupted.

Fields

length: u32

Chunk length.

maximum_length: u32

Chunk maximum expected length.



UnsupportedCompressionScheme

Currently are only 2 types of compression: Gzip and Zlib.

This should not occur under normal conditions.

Region file are corrupted or was introduced new compression type.

Fields

compression_scheme: u8

Compression scheme type id.



IOError

I/O Error which happened while were reading chunk data from region file.

Fields

io_error: Error


TagDecodeError

Error while decoding binary data to NBT tag.

This should not occur under normal conditions.

Region file are corrupted or a developer error in the NBT library.

Fields

tag_decode_error: TagDecodeError