pub enum ChunkReadError {
ChunkNotFound {
position: RegionChunkPosition,
},
LengthExceedsMaximum {
length: u32,
maximum_length: u32,
},
UnsupportedCompressionScheme {
compression_scheme: u8,
},
IOError {
io_error: Error,
},
TagDecodeError {
tag_decode_error: TagDecodeError,
},
}Expand description
Possible errors while loading the chunk.
Variants
ChunkNotFound
Chunk at specified coordinates inside region not found.
Fields

position: RegionChunkPositionLengthExceedsMaximum
Chunk length overlaps declared maximum.
This should not occur under normal conditions.
Region file are corrupted.
UnsupportedCompressionScheme
Currently are only 2 types of compression: Gzip and Zlib.
This should not occur under normal conditions.
Region file are corrupted or was introduced new compression type.
IOError
I/O Error which happened while were reading chunk data from region file.
TagDecodeError
Error while decoding binary data to NBT tag.
This should not occur under normal conditions.
Region file are corrupted or a developer error in the NBT library.
Fields

tag_decode_error: TagDecodeErrorTrait Implementations
Sourceimpl Debug for ChunkReadError
impl Debug for ChunkReadError
Sourceimpl From<Error> for ChunkReadError
impl From<Error> for ChunkReadError
Sourceimpl From<TagDecodeError> for ChunkReadError
impl From<TagDecodeError> for ChunkReadError
Sourcefn from(tag_decode_error: TagDecodeError) -> Self
fn from(tag_decode_error: TagDecodeError) -> Self
Converts to this type from the input type.